"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const FacebookSharePreview_1 = __importDefault(require("./FacebookSharePreview"));
const TwitterSharePreview_1 = __importDefault(require("./TwitterSharePreview"));
const LinkedinSharePreview_1 = __importDefault(require("./LinkedinSharePreview"));
const GooglePreview_1 = require("./GooglePreview");
require("../styles/socialPreview.css?raw");
const socialPreviewUtils_1 = require("./socialPreviewUtils");
function fallbackPrepare(doc) {
    var _a, _b;
    if (!doc) {
        return;
    }
    const description = doc.description || doc.metaDescription || doc.seoDescription;
    // Sane defaults to what we could use for title, description, etc.
    return {
        title: doc.title || '(page not yet named)',
        // @TODO: consider checking if
        description: typeof description === 'string'
            ? description
            : Array.isArray(description)
                ? socialPreviewUtils_1.toPlainText(description)
                : undefined,
        siteUrl: 'https://example.com',
        ogImage: doc.openGraphImage || doc.ogImage || doc.image,
        slug: ((_a = doc.slug) === null || _a === void 0 ? void 0 : _a.current) || ((_b = doc.relativePath) === null || _b === void 0 ? void 0 : _b.current),
    };
}
// @TODO: select object to make it easier to re-use prepare function logic
const SocialPreview = ({ prepareFunction = fallbackPrepare, google = true, twitter = true, linkedin = true, facebook = true, } = {}) => {
    return ({ document }) => {
        const previewProps = prepareFunction(document === null || document === void 0 ? void 0 : document.displayed);
        if (!previewProps) {
            return null;
        }
        return (react_1.default.createElement(react_1.default.Fragment, null,
            google && (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(GooglePreview_1.GoogleDesktop, Object.assign({}, previewProps)),
                react_1.default.createElement(GooglePreview_1.GoogleMobile, Object.assign({}, previewProps)))),
            facebook && react_1.default.createElement(FacebookSharePreview_1.default, Object.assign({}, previewProps)),
            twitter && react_1.default.createElement(TwitterSharePreview_1.default, Object.assign({}, previewProps)),
            linkedin && react_1.default.createElement(LinkedinSharePreview_1.default, Object.assign({}, previewProps))));
    };
};
exports.default = SocialPreview;
